@@ -383,8 +383,15 @@ static constexpr double kGetFileStatusInterval = 2.0; // seconds
 
     // we don't have a lock-file menuitem for folders
     // early return
-    if (is_dir)
+    if (is_dir) {
+        NSMenuItem *showUploadLinkByMenuItem =
+                [menu addItemWithTitle:NSLocalizedString(@"Get Seafile Upload Link",
+                                                         @"Get Seafile Upload Link")
+                                action:@selector(getUploadLinkAction:)
+                         keyEquivalent:@""];
+        [showUploadLinkByMenuItem setImage:seafileImage];
         return menu;
+    }
 
     // find where we have it
     auto file = file_status_.find(is_dir ? file_path + "/" : file_path);
@@ -621,4 +628,20 @@ static constexpr double kGetFileStatusInterval = 2.0; // seconds
     });
 }
 
+- (IBAction)getUploadLinkAction:(id)sender {
+    NSArray *items =
+            [[FIFinderSyncController defaultController] selectedItemURLs];
+    if (![items count])
+        return;
+    NSURL *item = items.firstObject;
+
+    // do it in another thread
+    std::string path =
+            item.path.precomposedStringWithCanonicalMapping.UTF8String;
+    dispatch_async(self.client_command_queue_, ^{
+        client_->doSendCommandWithPath(FinderSyncClient::DoGetUploadLink,
+                                       path.c_str());
+    });
+}
+
 @end
