@@ -80,9 +80,6 @@ class RepoDownloadInfo
 {
 public:
     int repo_version;
-    QString relay_id;
-    QString relay_addr;
-    QString relay_port;
     QString email;
     QString token;
     QString repo_id;
