@@ -70,6 +70,7 @@ static std::vector<LocalRepo> watch_set_;
 static std::unique_ptr<GetSharedLinkRequest, QtLaterDeleter> get_shared_link_req_;
 static std::unique_ptr<LockFileRequest, QtLaterDeleter> lock_file_req_;
 static std::unique_ptr<GetFileLockInfoRequest, QtLaterDeleter> get_lock_info_req_;
+static std::unique_ptr<GetUploadLinkRequest, QtLaterDeleter> get_upload_link_req_;
 
 FinderSyncHost::FinderSyncHost() : rpc_client_(new SeafileRpcClient) {
     rpc_client_->tryConnectDaemon();
@@ -358,3 +359,41 @@ void FinderSyncHost::onGetFileLockInfoFailed(const ApiError& error)
     const QString file = ::getBaseName(get_lock_info_req_->path());
     seafApplet->messageBox(tr("Failed to get lock information for file \"%1\"").arg(file));
 }
+
+void FinderSyncHost::doGetUploadLink(const QString &path)
+{
+    QString repo_id;
+    Account account;
+    QString path_in_repo;
+    if (!lookUpFileInformation(path, &repo_id, &account, &path_in_repo)) {
+        qWarning("[FinderSync] invalid path %s", path.toUtf8().data());
+        return;
+    }
+
+    // printf ("get upload link for %s\n", toCStr(path));
+    get_upload_link_req_.reset(new GetUploadLinkRequest(
+            account, repo_id, QString("/").append(path_in_repo)));
+
+    connect(get_upload_link_req_.get(), SIGNAL(success(const QString&)), this,
+            SLOT(onGetUploadLinkSuccess(const QString &)));
+    connect(get_upload_link_req_.get(), SIGNAL(failed(const ApiError&)), this,
+            SLOT(onGetUploadLinkFailed(const ApiError&)));
+
+    get_upload_link_req_->send();
+}
+
+void FinderSyncHost::onGetUploadLinkSuccess(const QString& upload_link)
+{
+    // printf ("get upload link is %s", toCStr(upload_link));
+    SharedLinkDialog *dialog = new SharedLinkDialog(upload_link, NULL, false);
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    dialog->show();
+    dialog->raise();
+    dialog->activateWindow();
+}
+
+void FinderSyncHost::onGetUploadLinkFailed(const ApiError& error)
+{
+    const QString file = ::getBaseName(get_upload_link_req_->path());
+    seafApplet->messageBox(tr("Failed to get upload link for file \"%1\"").arg(file));
+}
