@@ -195,14 +195,11 @@ void CreateRepoDialog::createSuccess(const RepoDownloadInfo& info)
     int ret = seafApplet->rpcClient()->cloneRepo(
         info.repo_id,
         info.repo_version,
-        info.relay_id,
         info.repo_name,
         path_,
         info.token,
         passwd_,
         info.magic,
-        info.relay_addr,
-        info.relay_port,
         info.email,
         info.random_key,
         info.enc_version,
