@@ -6,6 +6,7 @@
 #include <QTimer>
 #include <QDesktopServices>
 #include <QCloseEvent>
+#include <QAction>
 
 #include "QtAwesome.h"
 #include "utils/utils.h"
@@ -74,6 +75,8 @@ SyncErrorsDialog::SyncErrorsDialog(QWidget *parent)
     model_ = new SyncErrorsTableModel(this);
     table_->setModel(model_);
 
+    connect(table_, SIGNAL(refreshModel()), model_, SLOT(updateErrors()));
+
     QWidget* widget = new QWidget;
     widget->setObjectName("mainWidget");
     QVBoxLayout* layout = new QVBoxLayout;
@@ -179,11 +182,25 @@ void SyncErrorsTableView::contextMenuEvent(QContextMenuEvent *event)
 
 void SyncErrorsTableView::prepareContextMenu(const SyncError& error)
 {
+    id_ = error.id;
+}
+
+void SyncErrorsTableView::onDeleteFileAsyncError()
+{
+    bool success = seafApplet->rpcClient()->deleteFileAsyncErrorById(id_);
+    if (!success) {
+        seafApplet->messageBox(tr("Delete file async error failed"));
+        return;
+    }
+    emit refreshModel();
 }
 
 void SyncErrorsTableView::createContextMenu()
 {
     context_menu_ = new QMenu(this);
+    delete_action_ = new QAction("delete", this);
+    context_menu_->addAction(delete_action_);
+    connect(delete_action_, SIGNAL(triggered()), this, SLOT(onDeleteFileAsyncError()));
 }
 
 void SyncErrorsTableView::resizeEvent(QResizeEvent *event)
